@@ -1,12 +1,13 @@
 package Catalyst::Action::RenderView::ErrorHandler::Action::Log;
+{
+  $Catalyst::Action::RenderView::ErrorHandler::Action::Log::VERSION = '0.100166';
+}
 #ABSTRACT: A logging action for errors.
 
 use strict;
 use warnings;
 use Moose;
 
-our $VERSION = '0.100165';
-
 with 'Catalyst::Action::RenderView::ErrorHandler::Action';
 has 'level' => (is => 'ro', isa => 'Str', default => 'error');
 
@@ -25,10 +26,17 @@ sub perform {
 
 __END__
 
-=head1 DESCRIPTION
+=pod
 
-Really a rather useless example of an ErrorHandler action. It uses catalysts
-logging facilities to log errors.
+=encoding utf-8
+
+=head1 NAME
+
+Catalyst::Action::RenderView::ErrorHandler::Action::Log - A logging action for errors.
+
+=head1 VERSION
+
+version 0.100166
 
 =head1 SYNOPSIS
 
@@ -43,6 +51,11 @@ logging facilities to log errors.
                 actions:
                     - log-error
 
+=head1 DESCRIPTION
+
+Really a rather useless example of an ErrorHandler action. It uses catalysts
+logging facilities to log errors.
+
 =head1 INTERFACE
 
 =head2 INHERITED ACCESSORS
@@ -72,3 +85,15 @@ every error.
 
 Inherited from Moose.
 
+=head1 AUTHOR
+
+Andreas Marienborg <andremar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Andreas Marienborg.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
