@@ -1,10 +1,10 @@
 package TestApp4::View::Default;
 
-use base qw( Catalyst::View );
+use base qw( Catalyst::View::TT );
 
 sub process {
     my( $self, $c ) = @_;
-    $c->res->body('Everything is OK');
+    $self->maybe::next::method($c);
 }
 
 1;
